diff --git a/lib/modules.nix b/lib/modules.nix
index 3330579952de..e91a4d2afb92 100644
--- a/lib/modules.nix
+++ b/lib/modules.nix
@@ -1131,7 +1131,7 @@ let
defsFinal' =
let
# Process mkMerge and mkIf properties.
- defs' = concatMap (
+ defsNormalized = concatMap (
m:
map (
value:
@@ -1146,19 +1146,19 @@ let
) defs;
# Process mkOverride properties.
- defs'' = filterOverrides' defs';
+ defsFiltered = filterOverrides' defsNormalized;
# Sort mkOrder properties.
- defs''' =
+ defsSorted =
# Avoid sorting if we don't have to.
- if any (def: def.value._type or "" == "order") defs''.values then
- sortProperties defs''.values
+ if any (def: def.value._type or "" == "order") defsFiltered.values then
+ sortProperties defsFiltered.values
else
- defs''.values;
+ defsFiltered.values;
in
{
- values = defs''';
- inherit (defs'') highestPrio;
+ values = defsSorted;
+ inherit (defsFiltered) highestPrio;
};
defsFinal = defsFinal'.values;
diff --git a/nixos/doc/manual/release-notes/rl-2511.section.md b/nixos/doc/manual/release-notes/rl-2511.section.md
index 4adfc1aa90b3..0e003028a377 100644
--- a/nixos/doc/manual/release-notes/rl-2511.section.md
+++ b/nixos/doc/manual/release-notes/rl-2511.section.md
@@ -330,6 +330,8 @@
- `services.varnish.http_address` has been superseeded by `services.varnish.listen` which is now
structured config for all of varnish's `-a` variations.
+- `services.nginx.recommendedProxySettings` now sets `X-Forwarded-Server` to the hostname of nginx instead of the original host.
+
- [](#opt-services.gnome.gnome-keyring.enable) does not ship with an SSH agent anymore, as this is now handled by the `gcr_4` package instead of `gnome-keyring`. A new module has been added to support this, under [](#opt-services.gnome.gcr-ssh-agent.enable) (its default value has been set to [](#opt-services.gnome.gnome-keyring.enable) to ensure a smooth transition). See the [relevant upstream PR](https://gitlab.gnome.org/GNOME/gcr/-/merge_requests/67) for more details.
- The `nettools` package (ifconfig, arp, mii-tool, netstat, route) is not installed by default anymore. The suite is unmaintained and users should migrate to `iproute2` and `ethtool` instead.
diff --git a/nixos/modules/services/networking/mosquitto.nix b/nixos/modules/services/networking/mosquitto.nix
index c9e0a2738fa5..9ac643706d40 100644
--- a/nixos/modules/services/networking/mosquitto.nix
+++ b/nixos/modules/services/networking/mosquitto.nix
@@ -518,6 +518,7 @@ let
pid_file = 1;
queue_qos0_messages = 1;
retain_available = 1;
+ retain_expiry_interval = 1;
set_tcp_nodelay = 1;
sys_interval = 1;
upgrade_outgoing_qos = 1;
diff --git a/nixos/modules/services/web-apps/mealie.nix b/nixos/modules/services/web-apps/mealie.nix
index d2176c6b10b3..1b22fcfd35c8 100644
--- a/nixos/modules/services/web-apps/mealie.nix
+++ b/nixos/modules/services/web-apps/mealie.nix
@@ -39,6 +39,18 @@ in
};
};
+ extraOptions = lib.mkOption {
+ type = lib.types.listOf lib.types.str;
+ default = [ ];
+ example = [
+ "--log-level"
+ "debug"
+ ];
+ description = ''
+ Specifies extra command line arguments to pass to mealie (Gunicorn).
+ '';
+ };
+
credentialsFile = lib.mkOption {
type = with lib.types; nullOr path;
default = null;
@@ -84,7 +96,7 @@ in
DynamicUser = true;
User = "mealie";
ExecStartPre = "${pkg}/libexec/init_db";
- ExecStart = "${lib.getExe pkg} -b ${cfg.listenAddress}:${builtins.toString cfg.port}";
+ ExecStart = "${lib.getExe pkg} -b ${cfg.listenAddress}:${builtins.toString cfg.port} ${lib.escapeShellArgs cfg.extraOptions}";
EnvironmentFile = lib.mkIf (cfg.credentialsFile != null) cfg.credentialsFile;
StateDirectory = "mealie";
StandardOutput = "journal";
diff --git a/nixos/modules/services/web-apps/outline.nix b/nixos/modules/services/web-apps/outline.nix
index 9aa1fb09a43a..e61ef35df28e 100644
--- a/nixos/modules/services/web-apps/outline.nix
+++ b/nixos/modules/services/web-apps/outline.nix
@@ -702,7 +702,6 @@ in
FORCE_HTTPS = builtins.toString cfg.forceHttps;
ENABLE_UPDATES = builtins.toString cfg.enableUpdateCheck;
WEB_CONCURRENCY = builtins.toString cfg.concurrency;
- MAXIMUM_IMPORT_SIZE = builtins.toString cfg.maximumImportSize;
DEBUG = cfg.debugOutput;
GOOGLE_ANALYTICS_ID = lib.optionalString (cfg.googleAnalyticsId != null) cfg.googleAnalyticsId;
SENTRY_DSN = lib.optionalString (cfg.sentryDsn != null) cfg.sentryDsn;
@@ -715,6 +714,7 @@ in
RATE_LIMITER_DURATION_WINDOW = builtins.toString cfg.rateLimiter.durationWindow;
FILE_STORAGE = cfg.storage.storageType;
+ FILE_STORAGE_IMPORT_MAX_SIZE = builtins.toString cfg.maximumImportSize;
FILE_STORAGE_UPLOAD_MAX_SIZE = builtins.toString cfg.storage.uploadMaxSize;
FILE_STORAGE_LOCAL_ROOT_DIR = cfg.storage.localRootDir;
}
diff --git a/nixos/modules/services/web-servers/nginx/default.nix b/nixos/modules/services/web-servers/nginx/default.nix
index a29ad656cad9..04495f81c165 100644
--- a/nixos/modules/services/web-servers/nginx/default.nix
+++ b/nixos/modules/services/web-servers/nginx/default.nix
@@ -108,7 +108,7 @@ let
proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
proxy_set_header X-Forwarded-Proto $scheme;
proxy_set_header X-Forwarded-Host $host;
- proxy_set_header X-Forwarded-Server $host;
+ proxy_set_header X-Forwarded-Server $hostname;
'';
proxyCachePathConfig = concatStringsSep "\n" (
diff --git a/nixos/tests/all-tests.nix b/nixos/tests/all-tests.nix
index 59911be74381..c5797f37ce14 100644
--- a/nixos/tests/all-tests.nix
+++ b/nixos/tests/all-tests.nix
@@ -430,6 +430,7 @@ in
cyrus-imap = runTest ./cyrus-imap.nix;
dae = runTest ./dae.nix;
darling-dmg = runTest ./darling-dmg.nix;
+ dashy = runTest ./web-apps/dashy.nix;
davis = runTest ./davis.nix;
db-rest = runTest ./db-rest.nix;
dconf = runTest ./dconf.nix;
diff --git a/nixos/tests/docker-tools-nix-shell.nix b/nixos/tests/docker-tools-nix-shell.nix
index c2ae2124e0a1..e64db38e82cc 100644
--- a/nixos/tests/docker-tools-nix-shell.nix
+++ b/nixos/tests/docker-tools-nix-shell.nix
@@ -17,7 +17,7 @@ in
{ ... }:
{
virtualisation = {
- diskSize = 3072;
+ diskSize = 4000;
docker.enable = true;
};
};
diff --git a/nixos/tests/outline.nix b/nixos/tests/outline.nix
index 58c751d66f78..9dc6bab39ecc 100644
--- a/nixos/tests/outline.nix
+++ b/nixos/tests/outline.nix
@@ -1,15 +1,4 @@
-{ pkgs, lib, ... }:
-let
- accessKey = "BKIKJAA5BMMU2RHO6IBB";
- secretKey = "V7f1CwQqAcwo80UEIJEjc5gVQUSSx5ohQ9GSrr12";
- secretKeyFile = pkgs.writeText "outline-secret-key" ''
- ${secretKey}
- '';
- rootCredentialsFile = pkgs.writeText "minio-credentials-full" ''
- MINIO_ROOT_USER=${accessKey}
- MINIO_ROOT_PASSWORD=${secretKey}
- '';
-in
+{ lib, ... }:
{
name = "outline";
@@ -17,37 +6,19 @@ in
node.pkgsReadOnly = false;
- nodes.outline =
- { pkgs, config, ... }:
- {
- nixpkgs.config.allowUnfree = true;
- environment.systemPackages = [ pkgs.minio-client ];
- services.outline = {
- enable = true;
- forceHttps = false;
- storage = {
- inherit accessKey secretKeyFile;
- uploadBucketUrl = "http://localhost:9000";
- uploadBucketName = "outline";
- region = config.services.minio.region;
- };
- };
- services.minio = {
- enable = true;
- inherit rootCredentialsFile;
+ nodes.outline = {
+ virtualisation.memorySize = 2 * 1024;
+ nixpkgs.config.allowUnfree = true;
+ services.outline = {
+ enable = true;
+ forceHttps = false;
+ storage = {
+ storageType = "local";
};
};
+ };
testScript = ''
- machine.wait_for_unit("minio.service")
- machine.wait_for_open_port(9000)
-
- # Create a test bucket on the server
- machine.succeed(
- "mc alias set minio http://localhost:9000 ${accessKey} ${secretKey} --api s3v4"
- )
- machine.succeed("mc mb minio/outline")
-
outline.wait_for_unit("outline.service")
outline.wait_for_open_port(3000)
outline.succeed("curl --fail http://localhost:3000/")
diff --git a/nixos/tests/web-apps/dashy.nix b/nixos/tests/web-apps/dashy.nix
new file mode 100644
index 000000000000..39454b5b8d8a
--- /dev/null
+++ b/nixos/tests/web-apps/dashy.nix
@@ -0,0 +1,75 @@
+{ pkgs, lib, ... }:
+let
+
+ customSettings = {
+ pageInfo = {
+ title = "My Custom Dashy Title";
+ };
+
+ sections = [
+ {
+ name = "My Section";
+ items = [
+ {
+ name = "NixOS";
+ url = "https://nixos.org";
+ }
+ ];
+ }
+ ];
+ };
+
+ customSettingsYaml = (pkgs.formats.yaml_1_1 { }).generate "custom-conf.yaml" customSettings;
+in
+{
+ name = "dashy";
+ meta.maintainers = [ lib.maintainers.therealgramdalf ];
+
+ defaults =
+ { config, ... }:
+ {
+ services.dashy = {
+ enable = true;
+ virtualHost = {
+ enableNginx = true;
+ domain = "dashy.local";
+ };
+ };
+
+ networking.extraHosts = "127.0.0.1 dashy.local";
+
+ services.nginx.virtualHosts."${config.services.dashy.virtualHost.domain}".listen = [
+ {
+ addr = "127.0.0.1";
+ port = 80;
+ }
+ ];
+ };
+ nodes = {
+ machine = { };
+
+ machine-custom = {
+ services.dashy.settings = customSettings;
+ };
+ };
+
+ testScript = ''
+ start_all()
+ machine.wait_for_unit("nginx.service")
+ machine.wait_for_open_port(80)
+
+ actual = machine.succeed("curl -v --stderr - http://dashy.local/", timeout=10)
+ expected = "
Dashy"
+ assert expected in actual, \
+ f"unexpected reply from Dashy, expected: '{expected}' got: '{actual}'"
+
+ machine_custom.wait_for_unit("nginx.service")
+ machine_custom.wait_for_open_port(80)
+
+ actual_custom = machine_custom.succeed("curl -s --stderr - http://dashy.local/conf.yml", timeout=10).strip()
+ expected_custom = machine_custom.succeed("cat ${customSettingsYaml}").strip()
+
+ assert expected_custom == actual_custom, \
+ f"unexpected reply from Dashy, expected: '{expected_custom}' got: '{actual_custom}'"
+ '';
+}
diff --git a/pkgs/applications/emulators/libretro/cores/fbneo.nix b/pkgs/applications/emulators/libretro/cores/fbneo.nix
index 62d941899e5f..98a958f3dee2 100644
--- a/pkgs/applications/emulators/libretro/cores/fbneo.nix
+++ b/pkgs/applications/emulators/libretro/cores/fbneo.nix
@@ -5,13 +5,13 @@
}:
mkLibretroCore {
core = "fbneo";
- version = "0-unstable-2025-09-12";
+ version = "0-unstable-2025-09-23";
src = fetchFromGitHub {
owner = "libretro";
repo = "fbneo";
- rev = "1f7783651749e42a0e580acb5f5a1b5f43cc1467";
- hash = "sha256-ltjBzAGfUrB5Rl+0ugI6HIFptiCwhfIDOCeUQpHJsR4=";
+ rev = "2d05f6cd665d6a2f0a876e2f50192c3fce53ed65";
+ hash = "sha256-FQI8LPNYQDB1Jo04EGJGbgTncmwfzuTXj1GK9QsT8uQ=";
};
makefile = "Makefile";
diff --git a/pkgs/applications/networking/browsers/firefox/packages/firefox-beta.nix b/pkgs/applications/networking/browsers/firefox/packages/firefox-beta.nix
index 598f149244da..c1ac226816ff 100644
--- a/pkgs/applications/networking/browsers/firefox/packages/firefox-beta.nix
+++ b/pkgs/applications/networking/browsers/firefox/packages/firefox-beta.nix
@@ -9,7 +9,7 @@
buildMozillaMach rec {
pname = "firefox-beta";
- binaryName = pname;
+ binaryName = "firefox-beta";
version = "144.0b4";
applicationName = "Firefox Beta";
src = fetchurl {
diff --git a/pkgs/applications/networking/browsers/firefox/packages/firefox-devedition.nix b/pkgs/applications/networking/browsers/firefox/packages/firefox-devedition.nix
index 9fb46e612e35..e4889fd3f926 100644
--- a/pkgs/applications/networking/browsers/firefox/packages/firefox-devedition.nix
+++ b/pkgs/applications/networking/browsers/firefox/packages/firefox-devedition.nix
@@ -9,7 +9,7 @@
buildMozillaMach rec {
pname = "firefox-devedition";
- binaryName = pname;
+ binaryName = "firefox-devedition";
version = "144.0b4";
applicationName = "Firefox Developer Edition";
requireSigning = false;
diff --git a/pkgs/applications/networking/cluster/cni/default.nix b/pkgs/applications/networking/cluster/cni/default.nix
index 205e412c3cee..c052501035a5 100644
--- a/pkgs/applications/networking/cluster/cni/default.nix
+++ b/pkgs/applications/networking/cluster/cni/default.nix
@@ -10,7 +10,7 @@ buildGoModule rec {
src = fetchFromGitHub {
owner = "containernetworking";
- repo = pname;
+ repo = "cni";
rev = "v${version}";
hash = "sha256-xeajsM8ZIlI6Otv9CQhPfYaVQwmJ5QcFEn1xt6e/ivQ=";
};
diff --git a/pkgs/applications/networking/cluster/helm/plugins/helm-git.nix b/pkgs/applications/networking/cluster/helm/plugins/helm-git.nix
index b439df92a0cd..8268bbd30707 100644
--- a/pkgs/applications/networking/cluster/helm/plugins/helm-git.nix
+++ b/pkgs/applications/networking/cluster/helm/plugins/helm-git.nix
@@ -16,7 +16,7 @@ stdenv.mkDerivation rec {
src = fetchFromGitHub {
owner = "aslafy-z";
- repo = pname;
+ repo = "helm-git";
rev = "v${version}";
sha256 = "sha256-/J/RAFNsxwG9aiCe28daJmC2D6Gz7CrPjucqkhC++y0=";
};
diff --git a/pkgs/applications/networking/cluster/helm/plugins/helm-s3.nix b/pkgs/applications/networking/cluster/helm/plugins/helm-s3.nix
index d15c50118863..3130085b947f 100644
--- a/pkgs/applications/networking/cluster/helm/plugins/helm-s3.nix
+++ b/pkgs/applications/networking/cluster/helm/plugins/helm-s3.nix
@@ -10,7 +10,7 @@ buildGoModule rec {
src = fetchFromGitHub {
owner = "hypnoglow";
- repo = pname;
+ repo = "helm-s3";
rev = "v${version}";
hash = "sha256-9n/Dzgr/wYGgJq47FdNGPPpOFzTRt4VaK8HA06F5FIE=";
};
diff --git a/pkgs/applications/networking/cluster/helm/plugins/helm-secrets.nix b/pkgs/applications/networking/cluster/helm/plugins/helm-secrets.nix
index 14da3ef644e2..5856fd3cbc7c 100644
--- a/pkgs/applications/networking/cluster/helm/plugins/helm-secrets.nix
+++ b/pkgs/applications/networking/cluster/helm/plugins/helm-secrets.nix
@@ -17,7 +17,7 @@ stdenv.mkDerivation rec {
src = fetchFromGitHub {
owner = "jkroepke";
- repo = pname;
+ repo = "helm-secrets";
rev = "v${version}";
hash = "sha256-hno6+kik+U9XA7Mr9OnuuVidfc/xoqWRjMbBMI6M3QA=";
};
diff --git a/pkgs/applications/networking/cluster/helm/plugins/helm-unittest.nix b/pkgs/applications/networking/cluster/helm/plugins/helm-unittest.nix
index ff8a20376d53..a84241ff157a 100644
--- a/pkgs/applications/networking/cluster/helm/plugins/helm-unittest.nix
+++ b/pkgs/applications/networking/cluster/helm/plugins/helm-unittest.nix
@@ -9,8 +9,8 @@ buildGoModule rec {
version = "0.7.2";
src = fetchFromGitHub {
- owner = pname;
- repo = pname;
+ owner = "helm-unittest";
+ repo = "helm-unittest";
rev = "v${version}";
hash = "sha256-RWucFZlyVYV5pHFGP7x5I+SILAJ9k12R7l5o7WKGS/c=";
};
diff --git a/pkgs/applications/networking/cluster/nomad/default.nix b/pkgs/applications/networking/cluster/nomad/default.nix
index eb94b51aa3a9..089958bb7a7b 100644
--- a/pkgs/applications/networking/cluster/nomad/default.nix
+++ b/pkgs/applications/networking/cluster/nomad/default.nix
@@ -35,7 +35,7 @@ let
src = fetchFromGitHub {
owner = "hashicorp";
- repo = pname;
+ repo = "nomad";
rev = "v${version}";
inherit hash;
};
diff --git a/pkgs/applications/networking/icemon/default.nix b/pkgs/applications/networking/icemon/default.nix
index 43e9c2b8ebba..4b1ccf2776c2 100644
--- a/pkgs/applications/networking/icemon/default.nix
+++ b/pkgs/applications/networking/icemon/default.nix
@@ -19,7 +19,7 @@ mkDerivation rec {
src = fetchFromGitHub {
owner = "icecc";
- repo = pname;
+ repo = "icemon";
rev = "v${version}";
sha256 = "09jnipr67dhawbxfn69yh7mmjrkylgiqmd0gmc2limd3z15d7pgc";
};
diff --git a/pkgs/applications/networking/instant-messengers/linphone/default.nix b/pkgs/applications/networking/instant-messengers/linphone/default.nix
index 84bc3da601e6..da15ef2657a7 100644
--- a/pkgs/applications/networking/instant-messengers/linphone/default.nix
+++ b/pkgs/applications/networking/instant-messengers/linphone/default.nix
@@ -41,7 +41,7 @@ mkDerivation rec {
domain = "gitlab.linphone.org";
owner = "public";
group = "BC";
- repo = pname;
+ repo = "linphone-desktop";
rev = version;
hash = "sha256-Pu2tGKe3C1uR4lzXkC5sJFu8iJBqF76UfWJXYjPwBkc=";
};
diff --git a/pkgs/applications/networking/instant-messengers/pidgin/pidgin-plugins/pidgin-indicator/default.nix b/pkgs/applications/networking/instant-messengers/pidgin/pidgin-plugins/pidgin-indicator/default.nix
index 35002f0b5773..7b61d3592b04 100644
--- a/pkgs/applications/networking/instant-messengers/pidgin/pidgin-plugins/pidgin-indicator/default.nix
+++ b/pkgs/applications/networking/instant-messengers/pidgin/pidgin-plugins/pidgin-indicator/default.nix
@@ -16,7 +16,7 @@ stdenv.mkDerivation rec {
src = fetchFromGitHub {
owner = "philipl";
- repo = pname;
+ repo = "pidgin-indicator";
rev = version;
sha256 = "sha256-CdA/aUu+CmCRbVBKpJGydicqFQa/rEsLWS3MBKlH2/M=";
};
diff --git a/pkgs/applications/networking/instant-messengers/pidgin/pidgin-plugins/purple-mm-sms/default.nix b/pkgs/applications/networking/instant-messengers/pidgin/pidgin-plugins/purple-mm-sms/default.nix
index b002d1f08eec..624448e7fde2 100644
--- a/pkgs/applications/networking/instant-messengers/pidgin/pidgin-plugins/purple-mm-sms/default.nix
+++ b/pkgs/applications/networking/instant-messengers/pidgin/pidgin-plugins/purple-mm-sms/default.nix
@@ -15,7 +15,7 @@ stdenv.mkDerivation rec {
src = fetchFromGitLab {
domain = "source.puri.sm";
owner = "Librem5";
- repo = pname;
+ repo = "purple-mm-sms";
rev = "v${version}";
sha256 = "0917gjig35hmi6isqb62vhxd3lkc2nwdn13ym2gvzgcjfgjzjajr";
};
diff --git a/pkgs/applications/networking/instant-messengers/psi/default.nix b/pkgs/applications/networking/instant-messengers/psi/default.nix
index 0f386c884cc8..2f8b2ef4811c 100644
--- a/pkgs/applications/networking/instant-messengers/psi/default.nix
+++ b/pkgs/applications/networking/instant-messengers/psi/default.nix
@@ -19,7 +19,7 @@ mkDerivation rec {
version = "1.5";
src = fetchFromGitHub {
owner = "psi-im";
- repo = pname;
+ repo = "psi";
rev = version;
sha256 = "hXDZODHl14kimRlMQ1XjISQ2kk9NS78axVN3U21wkuM=";
fetchSubmodules = true;
diff --git a/pkgs/applications/networking/irc/weechat/scripts/weechat-autosort/default.nix b/pkgs/applications/networking/irc/weechat/scripts/weechat-autosort/default.nix
index c26792dbc0a2..8f577c8d148a 100644
--- a/pkgs/applications/networking/irc/weechat/scripts/weechat-autosort/default.nix
+++ b/pkgs/applications/networking/irc/weechat/scripts/weechat-autosort/default.nix
@@ -4,13 +4,13 @@
fetchFromGitHub,
}:
-stdenv.mkDerivation rec {
+stdenv.mkDerivation {
pname = "weechat-autosort";
version = "3.9";
src = fetchFromGitHub {
owner = "de-vri-es";
- repo = pname;
+ repo = "weechat-autosort";
rev = "d62fa8633015ebc2676060fcdae88c402977be46";
sha256 = "sha256-doYDRIWiuHam2i3r3J3BZuWEhopoN4jms/xPXGyypok=";
};
diff --git a/pkgs/applications/networking/irc/weechat/scripts/weechat-notify-send/default.nix b/pkgs/applications/networking/irc/weechat/scripts/weechat-notify-send/default.nix
index 5aebaf7c82cf..12115fd6e2d4 100644
--- a/pkgs/applications/networking/irc/weechat/scripts/weechat-notify-send/default.nix
+++ b/pkgs/applications/networking/irc/weechat/scripts/weechat-notify-send/default.nix
@@ -11,7 +11,7 @@ stdenv.mkDerivation rec {
src = fetchFromGitHub {
owner = "s3rvac";
- repo = pname;
+ repo = "weechat-notify-send";
rev = "v${version}";
sha256 = "sha256-7uw0IdRSxhPrLqdgECKB9eOrtFj+2HTILBhakKiRuNQ=";
};
diff --git a/pkgs/applications/networking/irc/weechat/scripts/weechat-otr/default.nix b/pkgs/applications/networking/irc/weechat/scripts/weechat-otr/default.nix
index 523fd6bf1c52..055bb141bcea 100644
--- a/pkgs/applications/networking/irc/weechat/scripts/weechat-otr/default.nix
+++ b/pkgs/applications/networking/irc/weechat/scripts/weechat-otr/default.nix
@@ -52,7 +52,7 @@ stdenv.mkDerivation rec {
version = "1.9.2";
src = fetchFromGitHub {
- repo = pname;
+ repo = "weechat-otr";
owner = "mmb";
rev = "v${version}";
sha256 = "1lngv98y6883vk8z2628cl4d5y8jxy39w8245gjdvshl8g18k5s2";
diff --git a/pkgs/applications/networking/mailreaders/thunderbird/packages.nix b/pkgs/applications/networking/mailreaders/thunderbird/packages.nix
index 78a5ba1d450a..ac7a101d784c 100644
--- a/pkgs/applications/networking/mailreaders/thunderbird/packages.nix
+++ b/pkgs/applications/networking/mailreaders/thunderbird/packages.nix
@@ -39,7 +39,7 @@ let
pname = "thunderbird";
inherit version updateScript applicationName;
application = "comm/mail";
- binaryName = pname;
+ binaryName = "thunderbird";
src = fetchurl {
url = "mirror://mozilla/thunderbird/releases/${version}/source/thunderbird-${version}.source.tar.xz";
inherit sha512;
diff --git a/pkgs/applications/networking/netmaker/default.nix b/pkgs/applications/networking/netmaker/default.nix
index 97fa456359ac..24101101ccf0 100644
--- a/pkgs/applications/networking/netmaker/default.nix
+++ b/pkgs/applications/networking/netmaker/default.nix
@@ -17,7 +17,7 @@ buildGoModule rec {
src = fetchFromGitHub {
owner = "gravitl";
- repo = pname;
+ repo = "netmaker";
rev = "v${version}";
hash = "sha256-acsIe3N6F76KktfPOHreFwDatyuv1q7ui6MMhVXfj7c=";
};
diff --git a/pkgs/applications/networking/p2p/libutp/3.4.nix b/pkgs/applications/networking/p2p/libutp/3.4.nix
index ae575bc8c396..20d966402fb4 100644
--- a/pkgs/applications/networking/p2p/libutp/3.4.nix
+++ b/pkgs/applications/networking/p2p/libutp/3.4.nix
@@ -6,14 +6,14 @@
unstableGitUpdater,
}:
-stdenv.mkDerivation rec {
+stdenv.mkDerivation {
pname = "libutp";
version = "0-unstable-2024-11-16";
src = fetchFromGitHub {
# Use transmission fork from post-3.4-transmission branch
owner = "transmission";
- repo = pname;
+ repo = "libutp";
rev = "490874c44a2ecf914404b0a20e043c9755fff47b";
hash = "sha256-ArUOr392s/rIplthSmHYXnqhO6i1PkkGV1jmQPQL7Yg=";
};
diff --git a/pkgs/applications/networking/p2p/libutp/default.nix b/pkgs/applications/networking/p2p/libutp/default.nix
index a9ba52e1b497..21d49ed832c3 100644
--- a/pkgs/applications/networking/p2p/libutp/default.nix
+++ b/pkgs/applications/networking/p2p/libutp/default.nix
@@ -5,14 +5,14 @@
cmake,
}:
-stdenv.mkDerivation rec {
+stdenv.mkDerivation {
pname = "libutp";
version = "unstable-2017-01-02";
src = fetchFromGitHub {
# Use transmission fork from post-3.3-transmission branch
owner = "transmission";
- repo = pname;
+ repo = "libutp";
rev = "fda9f4b3db97ccb243fcbed2ce280eb4135d705b";
sha256 = "CvuZLOBksIl/lS6LaqOIuzNvX3ihlIPjI3Eqwo7YJH0=";
};
diff --git a/pkgs/applications/office/pdfmixtool/default.nix b/pkgs/applications/office/pdfmixtool/default.nix
index 61443dddcde0..f19bd4dadf93 100644
--- a/pkgs/applications/office/pdfmixtool/default.nix
+++ b/pkgs/applications/office/pdfmixtool/default.nix
@@ -19,7 +19,7 @@ mkDerivation rec {
src = fetchFromGitLab {
owner = "scarpetta";
- repo = pname;
+ repo = "pdfmixtool";
rev = "v${version}";
hash = "sha256-fgtRKUG6J/CM6cXUTHWAPemqL8loWZT3wZmGdRHldq8=";
};
diff --git a/pkgs/applications/office/qnotero/default.nix b/pkgs/applications/office/qnotero/default.nix
index eba25348f306..2db93f97da52 100644
--- a/pkgs/applications/office/qnotero/default.nix
+++ b/pkgs/applications/office/qnotero/default.nix
@@ -14,7 +14,7 @@ python3Packages.buildPythonPackage rec {
src = fetchFromGitHub {
owner = "ealbiter";
- repo = pname;
+ repo = "qnotero";
tag = "v${version}";
sha256 = "sha256-Rym7neluRbYCpuezRQyLc6gSl3xbVR9fvhOxxW5+Nzo=";
};
diff --git a/pkgs/applications/radio/guglielmo/default.nix b/pkgs/applications/radio/guglielmo/default.nix
index 9836d03ee851..e1a81e9b40f1 100644
--- a/pkgs/applications/radio/guglielmo/default.nix
+++ b/pkgs/applications/radio/guglielmo/default.nix
@@ -22,7 +22,7 @@ mkDerivation rec {
src = fetchFromGitHub {
owner = "marcogrecopriolo";
- repo = pname;
+ repo = "guglielmo";
rev = "v${version}";
sha256 = "sha256-W+KTwtxbTDrtONmkw95gXT28n3k9KS364WOzLLJdGLM=";
};
diff --git a/pkgs/applications/science/biology/minc-tools/default.nix b/pkgs/applications/science/biology/minc-tools/default.nix
index 8cd3cf2b81ad..16f9a3e64db2 100644
--- a/pkgs/applications/science/biology/minc-tools/default.nix
+++ b/pkgs/applications/science/biology/minc-tools/default.nix
@@ -14,13 +14,13 @@
zlib,
}:
-stdenv.mkDerivation rec {
+stdenv.mkDerivation {
pname = "minc-tools";
version = "2.3.06-unstable-2023-08-12";
src = fetchFromGitHub {
owner = "BIC-MNI";
- repo = pname;
+ repo = "minc-tools";
rev = "c86a767dbb63aaa05ee981306fa09f6133bde427";
hash = "sha256-PLNcuDU0ht1PcjloDhrPzpOpE42gbhPP3rfHtP7WnM4=";
};
diff --git a/pkgs/applications/science/electronics/gerbv/default.nix b/pkgs/applications/science/electronics/gerbv/default.nix
index 9dd3e1a1d8e7..2865286b8d19 100644
--- a/pkgs/applications/science/electronics/gerbv/default.nix
+++ b/pkgs/applications/science/electronics/gerbv/default.nix
@@ -18,7 +18,7 @@ stdenv.mkDerivation rec {
src = fetchFromGitHub {
owner = "gerbv";
- repo = pname;
+ repo = "gerbv";
tag = "v${version}";
hash = "sha256-sr48RGLYcMKuyH9p+5BhnR6QpKBvNOqqtRryw3+pbBk=";
};
diff --git a/pkgs/applications/science/electronics/librepcb/default.nix b/pkgs/applications/science/electronics/librepcb/default.nix
index 34b430b07e10..34abc1d75534 100644
--- a/pkgs/applications/science/electronics/librepcb/default.nix
+++ b/pkgs/applications/science/electronics/librepcb/default.nix
@@ -20,8 +20,8 @@ stdenv.mkDerivation rec {
version = "1.3.0";
src = fetchFromGitHub {
- owner = pname;
- repo = pname;
+ owner = "librepcb";
+ repo = "librepcb";
rev = version;
hash = "sha256-J4y0ikZNuOguN9msmEQzgcY0/REnOEOoDkY/ga+Cfd8=";
fetchSubmodules = true;
diff --git a/pkgs/applications/science/electronics/nanovna-saver/default.nix b/pkgs/applications/science/electronics/nanovna-saver/default.nix
index eaadc55bb0e2..4740d026bbcb 100644
--- a/pkgs/applications/science/electronics/nanovna-saver/default.nix
+++ b/pkgs/applications/science/electronics/nanovna-saver/default.nix
@@ -23,7 +23,7 @@ python3.pkgs.buildPythonApplication rec {
src = fetchFromGitHub {
owner = "NanoVNA-Saver";
- repo = pname;
+ repo = "nanovna-saver";
tag = "v${version}";
sha256 = "sha256-Asx4drb9W2NobdgOlbgdm1aAzB69hnIWvOM915F7sgA=";
};
diff --git a/pkgs/applications/science/logic/easycrypt/default.nix b/pkgs/applications/science/logic/easycrypt/default.nix
index 629d5faea395..c58853a261bf 100644
--- a/pkgs/applications/science/logic/easycrypt/default.nix
+++ b/pkgs/applications/science/logic/easycrypt/default.nix
@@ -13,8 +13,8 @@ stdenv.mkDerivation rec {
version = "2025.08";
src = fetchFromGitHub {
- owner = pname;
- repo = pname;
+ owner = "easycrypt";
+ repo = "easycrypt";
tag = "r${version}";
hash = "sha256-WUms6hh7T5/gxRLFvbJQiT1ErLr8KFilFNOMTT/fIyY=";
};
diff --git a/pkgs/applications/science/math/engauge-digitizer/default.nix b/pkgs/applications/science/math/engauge-digitizer/default.nix
index f2f87a42ab8a..22fd209930a6 100644
--- a/pkgs/applications/science/math/engauge-digitizer/default.nix
+++ b/pkgs/applications/science/math/engauge-digitizer/default.nix
@@ -20,7 +20,7 @@ stdenv.mkDerivation rec {
src = fetchFromGitHub {
owner = "markummitchell";
- repo = pname;
+ repo = "engauge-digitizer";
rev = "v${version}";
sha256 = "sha256-Wj9o3wWbtHsEi6LFH4xDpwVR9BwcWc472jJ/QFDQZvY=";
};
diff --git a/pkgs/applications/science/math/speedcrunch/default.nix b/pkgs/applications/science/math/speedcrunch/default.nix
index 566c3a833943..0dde53043f80 100644
--- a/pkgs/applications/science/math/speedcrunch/default.nix
+++ b/pkgs/applications/science/math/speedcrunch/default.nix
@@ -8,13 +8,13 @@
qttools,
}:
-mkDerivation rec {
+mkDerivation {
pname = "speedcrunch";
version = "unstable-2021-10-09";
src = fetchFromBitbucket {
owner = "heldercorreia";
- repo = pname;
+ repo = "speedcrunch";
rev = "74756f3438149c01e9edc3259b0f411fa319a22f";
sha256 = "sha256-XxQv+A5SfYXFIRK7yacxGHHne1Q93pwCGeHhchIKizU=";
};
diff --git a/pkgs/applications/science/misc/vite/default.nix b/pkgs/applications/science/misc/vite/default.nix
index 917dc3d3b6a8..4684bccc31e0 100644
--- a/pkgs/applications/science/misc/vite/default.nix
+++ b/pkgs/applications/science/misc/vite/default.nix
@@ -13,14 +13,14 @@
wrapQtAppsHook,
}:
-stdenv.mkDerivation rec {
+stdenv.mkDerivation {
pname = "vite";
version = "unstable-2022-05-17";
src = fetchFromGitLab {
domain = "gitlab.inria.fr";
owner = "solverstack";
- repo = pname;
+ repo = "vite";
rev = "6d497cc519fac623e595bd174e392939c4de845c";
hash = "sha256-Yf2jYALZplIXzVtd/sg6gzEYrZ+oU0zLG1ETd/hiTi0=";
};
diff --git a/pkgs/applications/science/physics/crystfel/default.nix b/pkgs/applications/science/physics/crystfel/default.nix
index b3b17ba772f9..f91d119508ab 100644
--- a/pkgs/applications/science/physics/crystfel/default.nix
+++ b/pkgs/applications/science/physics/crystfel/default.nix
@@ -173,7 +173,7 @@ let
version = "0.1.0";
src = fetchFromGitHub {
owner = "nexusformat";
- repo = pname;
+ repo = "HDF5-External-Filter-Plugins";
rev = "49e3b65eca772bca77af13ba047d8b577673afba";
hash = "sha256-bEzfWdZuHmb0PDzCqy8Dey4tLtq+4coO0sT0GzqrTYI=";
};
diff --git a/pkgs/applications/science/robotics/mavproxy/default.nix b/pkgs/applications/science/robotics/mavproxy/default.nix
index 440312da1490..2550c9ee875f 100644
--- a/pkgs/applications/science/robotics/mavproxy/default.nix
+++ b/pkgs/applications/science/robotics/mavproxy/default.nix
@@ -22,7 +22,7 @@ buildPythonApplication rec {
src = fetchFromGitHub {
owner = "ArduPilot";
- repo = pname;
+ repo = "MAVProxy";
tag = "v${version}";
hash = "sha256-1/bp3vlCXt4Hg36zwMKSzPSxW7xlxpfx2o+2uQixdos=";
};
diff --git a/pkgs/applications/science/robotics/sumorobot-manager/default.nix b/pkgs/applications/science/robotics/sumorobot-manager/default.nix
index b729f9246d19..57c0fbc2cf1f 100644
--- a/pkgs/applications/science/robotics/sumorobot-manager/default.nix
+++ b/pkgs/applications/science/robotics/sumorobot-manager/default.nix
@@ -16,7 +16,7 @@ stdenv.mkDerivation rec {
src = fetchFromGitHub {
owner = "robokoding";
- repo = pname;
+ repo = "sumorobot-manager";
rev = "v${version}";
sha256 = "07snhwmqqp52vdgr66vx50zxx0nmpmns5cdjgh50hzlhji2z1fl9";
};
diff --git a/pkgs/by-name/ai/airdrop-cli/package.nix b/pkgs/by-name/ai/airdrop-cli/package.nix
index 805fd28bcbbd..0b60f966e5d6 100644
--- a/pkgs/by-name/ai/airdrop-cli/package.nix
+++ b/pkgs/by-name/ai/airdrop-cli/package.nix
@@ -9,13 +9,13 @@
# Doesn't build without using the same stdenv (and Clang) to build swift
swiftPackages.stdenv.mkDerivation {
pname = "airdrop-cli";
- version = "0-unstable-2024-04-13";
+ version = "0-unstable-2025-07-14";
src = fetchFromGitHub {
owner = "vldmrkl";
repo = "airdrop-cli";
- rev = "dcdd570c3af3aae509ba7ad9fb26782b427f3a1a";
- hash = "sha256-7gKKeedRayf27XrOhntu41AMXgxc7fqJRE8Jhbihh3o=";
+ rev = "8bb7d64c9f9ce1166405aa5b9a11f00dcc466ea0";
+ hash = "sha256-aaczNVDJhkzeaSBXP+HmgHGZWVztggwv3OtTBAFCFvk=";
};
nativeBuildInputs = [
diff --git a/pkgs/by-name/di/difftastic/package.nix b/pkgs/by-name/di/difftastic/package.nix
index de2580e0975e..78d77621ff58 100644
--- a/pkgs/by-name/di/difftastic/package.nix
+++ b/pkgs/by-name/di/difftastic/package.nix
@@ -9,16 +9,16 @@
rustPlatform.buildRustPackage (finalAttrs: {
pname = "difftastic";
- version = "0.64.0";
+ version = "0.65.0";
src = fetchFromGitHub {
owner = "wilfred";
repo = "difftastic";
tag = finalAttrs.version;
- hash = "sha256-XMvysYO6Kji9cbfGayB6wPVuNp0j2uXLHfZ9H+dBLt0=";
+ hash = "sha256-w4z1ljIjPQQYPpMGgrcptTYeP5S72iVvVgNvrctN61w=";
};
- cargoHash = "sha256-1u3oUbqhwHXD90ld70pjK2XPJe5hpUbJtU78QpIjAE8=";
+ cargoHash = "sha256-qj2CyHlEVxTo3wsmuivpnhx02/gMbZjmpAM3dp4xXEQ=";
env = lib.optionalAttrs stdenv.hostPlatform.isStatic { RUSTFLAGS = "-C relocation-model=static"; };
diff --git a/pkgs/by-name/eg/egctl/package.nix b/pkgs/by-name/eg/egctl/package.nix
new file mode 100644
index 000000000000..421be11a2cc1
--- /dev/null
+++ b/pkgs/by-name/eg/egctl/package.nix
@@ -0,0 +1,66 @@
+{
+ stdenv,
+ buildGoModule,
+ fetchFromGitHub,
+ installShellFiles,
+ lib,
+ testers,
+}:
+
+buildGoModule (finalAttrs: {
+ pname = "egctl";
+ version = "1.5.1";
+
+ src = fetchFromGitHub {
+ owner = "envoyproxy";
+ repo = "gateway";
+ tag = "v${finalAttrs.version}";
+ hash = "sha256-glOnAnNuefdTq4BOd1NKpsadrWEqVOOc18jPx7lEwEQ=";
+ };
+
+ vendorHash =
+ if stdenv.buildPlatform.isDarwin then
+ "sha256-GoaucckTuJIvaq1/3R1rPDr3Nm8q27OICisomKXYJ28="
+ else
+ "sha256-+RTnsUg2LNSQ6pB99ikAKxd3q6IRhp2LHdBznYrHm4o=";
+
+ subPackages = [
+ "cmd/egctl"
+ "internal/cmd/egctl"
+ ];
+
+ ldflags = [
+ "-s"
+ "-w"
+ "-X github.com/envoyproxy/gateway/internal/cmd/version.envoyGatewayVersion=v${finalAttrs.version}"
+ ];
+
+ env.CGO_ENABLED = 0;
+
+ nativeBuildInputs = [ installShellFiles ];
+
+ postInstall = lib.optionalString (stdenv.buildPlatform.canExecute stdenv.hostPlatform) ''
+ $out/bin/egctl completion bash >egctl.bash
+ $out/bin/egctl completion fish >egctl.fish
+ $out/bin/egctl completion zsh >egctl.zsh
+ installShellCompletion egctl.{bash,fish,zsh}
+ '';
+
+ passthru.tests = {
+ version = testers.testVersion {
+ package = finalAttrs.finalPackage;
+ command = "egctl version --remote=false";
+ version = "v${finalAttrs.version}";
+ };
+ };
+
+ __darwinAllowLocalNetworking = true;
+
+ meta = {
+ description = "Command-line utility for operating Envoy Gateway";
+ homepage = "https://gateway.envoyproxy.io";
+ license = lib.licenses.asl20;
+ maintainers = [ lib.maintainers.maxbrunet ];
+ mainProgram = "egctl";
+ };
+})
diff --git a/pkgs/by-name/gh/gh-f/package.nix b/pkgs/by-name/gh/gh-f/package.nix
index b169a7f26bbc..56645eec3f37 100644
--- a/pkgs/by-name/gh/gh-f/package.nix
+++ b/pkgs/by-name/gh/gh-f/package.nix
@@ -15,13 +15,13 @@
stdenvNoCC.mkDerivation (finalAttrs: {
pname = "gh-f";
- version = "1.8.0";
+ version = "1.9.0";
src = fetchFromGitHub {
owner = "gennaro-tedesco";
repo = "gh-f";
tag = "v${finalAttrs.version}";
- hash = "sha256-quljviONCNnXC7QxTWE64PNt8IYr2GnaYq0cM/Pcl68=";
+ hash = "sha256-QWk9bGjfsIFa/0kAmA2QUmk87iyHdlvblYxML5XmbJ8=";
};
nativeBuildInputs = [ makeBinaryWrapper ];
diff --git a/pkgs/by-name/gi/git-crypt/package.nix b/pkgs/by-name/gi/git-crypt/package.nix
index e83dbe7e7adb..282b079017b1 100644
--- a/pkgs/by-name/gi/git-crypt/package.nix
+++ b/pkgs/by-name/gi/git-crypt/package.nix
@@ -12,13 +12,13 @@
stdenv.mkDerivation rec {
pname = "git-crypt";
- version = "0.7.0";
+ version = "0.8.0";
src = fetchFromGitHub {
owner = "AGWA";
repo = "git-crypt";
rev = version;
- sha256 = "sha256-GcGCX6hoKL+sNLAeGEzZpaM+cdFjcNlwYExfOFEPi0I=";
+ sha256 = "sha256-d5nMDFQkJY+obYkhvr8yT9mjlGEBWFLN5xGizJ9kwHw=";
};
strictDeps = true;
diff --git a/pkgs/by-name/gi/gitnuro/package.nix b/pkgs/by-name/gi/gitnuro/package.nix
index b57d50a74af0..f07b58723a7a 100644
--- a/pkgs/by-name/gi/gitnuro/package.nix
+++ b/pkgs/by-name/gi/gitnuro/package.nix
@@ -11,18 +11,18 @@
stdenv.mkDerivation rec {
pname = "gitnuro";
- version = "1.4.2";
+ version = "1.5.0";
src = fetchurl (
if stdenv.hostPlatform.system == "x86_64-linux" then
{
url = "https://github.com/JetpackDuba/Gitnuro/releases/download/v${version}/Gitnuro-linux-x86_64-${version}.jar";
- hash = "sha256-1lwuLPR6b1+I2SWaYaVrZkMcYVRAf1R7j/AwjQf03UM=";
+ hash = "sha256-EoBjw98O5gO2wTO34KMiFeteryYapZC83MUfIqxtbmQ=";
}
else if stdenv.hostPlatform.system == "aarch64-linux" then
{
url = "https://github.com/JetpackDuba/Gitnuro/releases/download/v${version}/Gitnuro-linux-arm_aarch64-${version}.jar";
- hash = "sha256-wnHW1YK4FKi5EDF/E0S+yr0tugtv3qVlCbT3+x9bM8s=";
+ hash = "sha256-oAmCapu9xFS1LMasj21q39Q/4yjLh6MZx79tC8Yjlec=";
}
else
throw "Unsupported architecture: ${stdenv.hostPlatform.system}"
diff --git a/pkgs/by-name/go/gotip/package.nix b/pkgs/by-name/go/gotip/package.nix
new file mode 100644
index 000000000000..9b1356181f9d
--- /dev/null
+++ b/pkgs/by-name/go/gotip/package.nix
@@ -0,0 +1,40 @@
+{
+ lib,
+ buildGoModule,
+ fetchFromGitHub,
+ versionCheckHook,
+ nix-update-script,
+}:
+
+buildGoModule (finalAttrs: {
+ pname = "gotip";
+ version = "0.5.0";
+
+ src = fetchFromGitHub {
+ owner = "lusingander";
+ repo = "gotip";
+ tag = "v${finalAttrs.version}";
+ hash = "sha256-z5Xk+lTDAvkMOJAR6eIC6rg+CP9wv+CSANdgj+KmPjA=";
+ };
+
+ vendorHash = "sha256-AgyFhoyPyXN5ngTi8iKzbx0wOqlu64gFdrygPOFHZT4=";
+
+ ldflags = [
+ "-s"
+ "-w"
+ ];
+
+ doInstallCheck = true;
+ nativeInstallCheckInputs = [ versionCheckHook ];
+ versionCheckProgramArg = "--version";
+
+ passthru.updateScript = nix-update-script { };
+
+ meta = {
+ description = "Go test interactive picker";
+ homepage = "https://github.com/lusingander/gotip";
+ license = lib.licenses.mit;
+ maintainers = with lib.maintainers; [ yiyu ];
+ mainProgram = "gotip";
+ };
+})
diff --git a/pkgs/by-name/gr/grimblast/package.nix b/pkgs/by-name/gr/grimblast/package.nix
index 6ba590401fd2..7cfe020022fd 100644
--- a/pkgs/by-name/gr/grimblast/package.nix
+++ b/pkgs/by-name/gr/grimblast/package.nix
@@ -18,13 +18,13 @@
stdenvNoCC.mkDerivation (finalAttrs: {
pname = "grimblast";
- version = "0.1-unstable-2025-08-20";
+ version = "0.1-unstable-2025-09-22";
src = fetchFromGitHub {
owner = "hyprwm";
repo = "contrib";
- rev = "04721247f417256ca96acf28cdfe946cf1006263";
- hash = "sha256-g7/g5o0spemkZCzPa8I21RgCmN0Kv41B5z9Z5HQWraY=";
+ rev = "de79078fd59140067e53cd00ebdf17f96ce27846";
+ hash = "sha256-iRv5afKzuu6SkwztqMwZ33161CzBJsyeRHp0uviN9TI=";
};
strictDeps = true;
diff --git a/pkgs/by-name/li/lima-additional-guestagents/package.nix b/pkgs/by-name/li/lima/additional-guestagents.nix
similarity index 82%
rename from pkgs/by-name/li/lima-additional-guestagents/package.nix
rename to pkgs/by-name/li/lima/additional-guestagents.nix
index 2733e990996d..ad80a7aad745 100644
--- a/pkgs/by-name/li/lima-additional-guestagents/package.nix
+++ b/pkgs/by-name/li/lima/additional-guestagents.nix
@@ -2,24 +2,17 @@
lib,
stdenv,
buildGoModule,
- fetchFromGitHub,
- nix-update-script,
+ callPackage,
apple-sdk_15,
findutils,
}:
buildGoModule (finalAttrs: {
pname = "lima-additional-guestagents";
- version = "1.2.1";
- src = fetchFromGitHub {
- owner = "lima-vm";
- repo = "lima";
- tag = "v${finalAttrs.version}";
- hash = "sha256-90fFsS5jidaovE2iqXfe4T2SgZJz6ScOwPPYxCsCk/k=";
- };
-
- vendorHash = "sha256-8S5tAL7GY7dxNdyC+WOrOZ+GfTKTSX84sG8WcSec2Os=";
+ # Because agents must use the same version as lima, lima's updateScript should also update the shared src.
+ # nixpkgs-update: no auto update
+ inherit (callPackage ./source.nix { }) version src vendorHash;
buildInputs = lib.optionals stdenv.hostPlatform.isDarwin [
apple-sdk_15
@@ -63,10 +56,6 @@ buildGoModule (finalAttrs: {
runHook postInstallCheck
'';
- passthru = {
- updateScript = nix-update-script { };
- };
-
meta = {
homepage = "https://github.com/lima-vm/lima";
description = "Lima Guest Agents for emulating non-native architectures";
diff --git a/pkgs/by-name/li/lima/package.nix b/pkgs/by-name/li/lima/package.nix
index 12ff0ee0705e..377a20665201 100644
--- a/pkgs/by-name/li/lima/package.nix
+++ b/pkgs/by-name/li/lima/package.nix
@@ -2,7 +2,7 @@
lib,
stdenv,
buildGoModule,
- fetchFromGitHub,
+ callPackage,
installShellFiles,
qemu,
darwin,
@@ -22,16 +22,8 @@
buildGoModule (finalAttrs: {
pname = "lima";
- version = "1.2.1";
- src = fetchFromGitHub {
- owner = "lima-vm";
- repo = "lima";
- tag = "v${finalAttrs.version}";
- hash = "sha256-90fFsS5jidaovE2iqXfe4T2SgZJz6ScOwPPYxCsCk/k=";
- };
-
- vendorHash = "sha256-8S5tAL7GY7dxNdyC+WOrOZ+GfTKTSX84sG8WcSec2Os=";
+ inherit (callPackage ./source.nix { }) version src vendorHash;
nativeBuildInputs = [
makeWrapper
@@ -159,7 +151,12 @@ buildGoModule (finalAttrs: {
};
};
- updateScript = nix-update-script { };
+ updateScript = nix-update-script {
+ extraArgs = [
+ "--override-filename"
+ ./source.nix
+ ];
+ };
};
meta = {
diff --git a/pkgs/by-name/li/lima/source.nix b/pkgs/by-name/li/lima/source.nix
new file mode 100644
index 000000000000..aa1134c22f91
--- /dev/null
+++ b/pkgs/by-name/li/lima/source.nix
@@ -0,0 +1,19 @@
+{
+ fetchFromGitHub,
+}:
+
+let
+ version = "1.2.1";
+in
+{
+ inherit version;
+
+ src = fetchFromGitHub {
+ owner = "lima-vm";
+ repo = "lima";
+ tag = "v${version}";
+ hash = "sha256-90fFsS5jidaovE2iqXfe4T2SgZJz6ScOwPPYxCsCk/k=";
+ };
+
+ vendorHash = "sha256-8S5tAL7GY7dxNdyC+WOrOZ+GfTKTSX84sG8WcSec2Os=";
+}
diff --git a/pkgs/by-name/ob/oboete/package.nix b/pkgs/by-name/ob/oboete/package.nix
index 5d8881a352f9..0297777c755c 100644
--- a/pkgs/by-name/ob/oboete/package.nix
+++ b/pkgs/by-name/ob/oboete/package.nix
@@ -9,16 +9,16 @@
rustPlatform.buildRustPackage (finalAttrs: {
pname = "oboete";
- version = "0.1.11";
+ version = "0.1.12";
src = fetchFromGitHub {
owner = "mariinkys";
repo = "oboete";
tag = finalAttrs.version;
- hash = "sha256-NRfNabOA09ILbjtvzkSGd3JdDzLRmOeQHQqRDEBHMAA=";
+ hash = "sha256-npvv2ZuMoZJnuwzRzbH+kQ5/IjlS6QuLi2rDmKwSoWQ=";
};
- cargoHash = "sha256-gGVibSf03BewM1nQDDtNFTJdYqiB3LErKmlF0Nf66kQ=";
+ cargoHash = "sha256-hOvITZJfFyJbCV9+SuyVVwsY1/OGRXlJeKB/opVGrnI=";
nativeBuildInputs = [ libcosmicAppHook ];
diff --git a/pkgs/by-name/po/poetry/package.nix b/pkgs/by-name/po/poetry/package.nix
index 2422753a8ab4..26cd52f672a6 100644
--- a/pkgs/by-name/po/poetry/package.nix
+++ b/pkgs/by-name/po/poetry/package.nix
@@ -18,12 +18,12 @@ let
# We keep the override around even when the versions match, as
# it's likely to become relevant again after the next Poetry update.
poetry-core = super.poetry-core.overridePythonAttrs (old: rec {
- version = "2.2.0";
+ version = "2.2.1";
src = fetchFromGitHub {
owner = "python-poetry";
repo = "poetry-core";
tag = version;
- hash = "sha256-WLPG8BiM+927qSC+ly5H2IAE2Htm8+wLEjK2AFnMJ58=";
+ hash = "sha256-l5WTjKa+A66QfWLmrjCQq7ZrSaeuylGIRZr8jsiYq+A=";
};
});
}
diff --git a/pkgs/by-name/po/poetry/unwrapped.nix b/pkgs/by-name/po/poetry/unwrapped.nix
index c6de126c84a1..07ab350567e3 100644
--- a/pkgs/by-name/po/poetry/unwrapped.nix
+++ b/pkgs/by-name/po/poetry/unwrapped.nix
@@ -37,7 +37,7 @@
buildPythonPackage rec {
pname = "poetry";
- version = "2.2.0";
+ version = "2.2.1";
pyproject = true;
disabled = pythonOlder "3.9";
@@ -46,7 +46,7 @@ buildPythonPackage rec {
owner = "python-poetry";
repo = "poetry";
tag = version;
- hash = "sha256-CI3+0P+eIFpdnyxy1zhaEMWAsX/R0qqdAvVEQ5fqnhk=";
+ hash = "sha256-oPHRDYci4lrZBY3MC4QU1juwbMJYFDJjARg1Y8us4FQ=";
};
build-system = [
diff --git a/pkgs/by-name/sc/scalapack/package.nix b/pkgs/by-name/sc/scalapack/package.nix
index c66dc0bc2839..6dfbf1891946 100644
--- a/pkgs/by-name/sc/scalapack/package.nix
+++ b/pkgs/by-name/sc/scalapack/package.nix
@@ -4,26 +4,33 @@
fetchFromGitHub,
fetchpatch,
cmake,
+ gfortran,
mpiCheckPhaseHook,
mpi,
blas,
lapack,
+ testers,
}:
assert blas.isILP64 == lapack.isILP64;
-stdenv.mkDerivation rec {
+stdenv.mkDerivation (finalAttrs: {
pname = "scalapack";
version = "2.2.2";
src = fetchFromGitHub {
owner = "Reference-ScaLAPACK";
repo = "scalapack";
- tag = "v${version}";
+ tag = "v${finalAttrs.version}";
hash = "sha256-KDMW/D7ubGaD2L7eTwULJ04fAYDPAKl8xKPZGZMkeik=";
};
- passthru = { inherit (blas) isILP64; };
+ passthru = {
+ inherit (blas) isILP64;
+ tests.pkg-config = testers.hasPkgConfigModules {
+ package = finalAttrs.finalPackage;
+ };
+ };
__structuredAttrs = true;
@@ -43,7 +50,7 @@ stdenv.mkDerivation rec {
# Required to activate ILP64.
# See https://github.com/Reference-ScaLAPACK/scalapack/pull/19
- postPatch = lib.optionalString passthru.isILP64 ''
+ postPatch = lib.optionalString finalAttrs.passthru.isILP64 ''
sed -i 's/INTSZ = 4/INTSZ = 8/g' TESTING/EIG/* TESTING/LIN/*
sed -i 's/INTGSZ = 4/INTGSZ = 8/g' TESTING/EIG/* TESTING/LIN/*
@@ -56,36 +63,35 @@ stdenv.mkDerivation rec {
"dev"
];
- nativeBuildInputs = [ cmake ];
+ nativeBuildInputs = [
+ cmake
+ gfortran
+ ];
+
nativeCheckInputs = [ mpiCheckPhaseHook ];
- buildInputs = [
+
+ propagatedBuildInputs = [
blas
lapack
- ];
- propagatedBuildInputs = [ mpi ];
- hardeningDisable = lib.optionals (stdenv.hostPlatform.isAarch64 && stdenv.hostPlatform.isDarwin) [
- "stackprotector"
+ mpi
];
# xslu and xsllt tests seem to time out on x86_64-darwin.
# this line is left so those who force installation on x86_64-darwin can still build
doCheck = !(stdenv.hostPlatform.isx86_64 && stdenv.hostPlatform.isDarwin);
- preConfigure = ''
- cmakeFlagsArray+=(
- -DBUILD_SHARED_LIBS=ON -DBUILD_STATIC_LIBS=OFF
- -DLAPACK_LIBRARIES="-llapack"
- -DBLAS_LIBRARIES="-lblas"
- -DCMAKE_Fortran_COMPILER=${lib.getDev mpi}/bin/mpif90
- -DCMAKE_C_FLAGS="${
- lib.concatStringsSep " " [
- "-Wno-implicit-function-declaration"
- (lib.optionalString passthru.isILP64 "-DInt=long")
- ]
- }"
- ${lib.optionalString passthru.isILP64 ''-DCMAKE_Fortran_FLAGS="-fdefault-integer-8"''}
- )
- '';
+ cmakeFlagsArray = [
+ (lib.cmakeBool "BUILD_SHARED_LIBS" (!stdenv.hostPlatform.isStatic))
+ (lib.cmakeFeature "LAPACK_LIBRARIES" "-llapack")
+ (lib.cmakeFeature "BLAS_LIBRARIES" "-lblas")
+ (lib.cmakeFeature "CMAKE_C_FLAGS" "${lib.concatStringsSep " " [
+ "-Wno-implicit-function-declaration"
+ (lib.optionalString finalAttrs.passthru.isILP64 "-DInt=long")
+ ]}")
+ ]
+ ++ lib.optionals finalAttrs.passthru.isILP64 [
+ (lib.cmakeFeature "CMAKE_Fortran_FLAGS" "-fdefault-integer-8")
+ ];
# Increase individual test timeout from 1500s to 10000s because hydra's builds
# sometimes fail due to this
@@ -95,16 +101,17 @@ stdenv.mkDerivation rec {
# _IMPORT_PREFIX, used to point to lib, points to dev output. Every package using the generated
# cmake file will thus look for the library in the dev output instead of out.
# Use the absolute path to $out instead to fix the issue.
- substituteInPlace $dev/lib/cmake/scalapack-${version}/scalapack-targets-release.cmake \
+ substituteInPlace $dev/lib/cmake/scalapack-${finalAttrs.version}/scalapack-targets-release.cmake \
--replace "\''${_IMPORT_PREFIX}" "$out"
'';
- meta = with lib; {
+ meta = {
homepage = "http://www.netlib.org/scalapack/";
description = "Library of high-performance linear algebra routines for parallel distributed memory machines";
- license = licenses.bsd3;
- platforms = platforms.unix;
- maintainers = with maintainers; [
+ license = lib.licenses.bsd3;
+ platforms = lib.platforms.unix;
+ pkgConfigModules = [ "scalapack" ];
+ maintainers = with lib.maintainers; [
costrouc
markuskowa
gdinh
@@ -112,4 +119,4 @@ stdenv.mkDerivation rec {
# xslu and xsllt tests fail on x86 darwin
broken = stdenv.hostPlatform.isDarwin && stdenv.hostPlatform.isx86_64;
};
-}
+})
diff --git a/pkgs/by-name/to/tombi/package.nix b/pkgs/by-name/to/tombi/package.nix
index 1c98e19275f3..09aa173775c2 100644
--- a/pkgs/by-name/to/tombi/package.nix
+++ b/pkgs/by-name/to/tombi/package.nix
@@ -1,8 +1,10 @@
{
+ stdenv,
lib,
rustPlatform,
fetchFromGitHub,
versionCheckHook,
+ installShellFiles,
}:
rustPlatform.buildRustPackage (finalAttrs: {
@@ -26,9 +28,19 @@ rustPlatform.buildRustPackage (finalAttrs: {
--replace-fail 'version = "0.0.0-dev"' 'version = "${finalAttrs.version}"'
'';
+ nativeBuildInputs = [ installShellFiles ];
+
+ postInstall = lib.optionalString (stdenv.buildPlatform.canExecute stdenv.hostPlatform) ''
+ installShellCompletion --cmd tombi \
+ --bash <($out/bin/tombi completion bash) \
+ --fish <($out/bin/tombi completion fish) \
+ --zsh <($out/bin/tombi completion zsh)
+ '';
+
nativeInstallCheckInputs = [
versionCheckHook
];
+
doInstallCheck = true;
meta = {
diff --git a/pkgs/by-name/ve/verilator/package.nix b/pkgs/by-name/ve/verilator/package.nix
index bb5cf627c148..ef657ead72a5 100644
--- a/pkgs/by-name/ve/verilator/package.nix
+++ b/pkgs/by-name/ve/verilator/package.nix
@@ -19,7 +19,7 @@
stdenv.mkDerivation rec {
pname = "verilator";
- version = "5.038";
+ version = "5.040";
# Verilator gets the version from this environment variable
# if it can't do git describe while building.
@@ -28,8 +28,8 @@ stdenv.mkDerivation rec {
src = fetchFromGitHub {
owner = "verilator";
repo = "verilator";
- rev = "v${version}";
- hash = "sha256-uPGVE7y3zm+5ZydGjd1+/kIjW+a5u6d+YzjUSE4KnCY=";
+ tag = "v${version}";
+ hash = "sha256-S+cDnKOTPjLw+sNmWL3+Ay6+UM8poMadkyPSGd3hgnc=";
};
enableParallelBuilding = true;
@@ -93,6 +93,7 @@ stdenv.mkDerivation rec {
};
meta = with lib; {
+ changelog = "https://github.com/verilator/verilator/blob/${src.tag}/Changes";
description = "Fast and robust (System)Verilog simulator/compiler and linter";
homepage = "https://www.veripool.org/verilator";
license = with licenses; [
diff --git a/pkgs/development/python-modules/aiohttp-client-cache/default.nix b/pkgs/development/python-modules/aiohttp-client-cache/default.nix
index 2537fd7393a4..62770c1fbebe 100644
--- a/pkgs/development/python-modules/aiohttp-client-cache/default.nix
+++ b/pkgs/development/python-modules/aiohttp-client-cache/default.nix
@@ -21,13 +21,13 @@
buildPythonPackage rec {
pname = "aiohttp-client-cache";
- version = "0.13.0";
+ version = "0.14.0";
pyproject = true;
src = fetchPypi {
pname = "aiohttp_client_cache";
inherit version;
- hash = "sha256-3FzWI0CtvuGOD+3HsMN1Qmkt8I+O2ZRddRtykqBDOFM=";
+ hash = "sha256-onEcLEhhTLljQ57No49shj5Jv6bqF1t9/7z1yCRfzxk=";
};
build-system = [ poetry-core ];
diff --git a/pkgs/development/python-modules/aranet4/default.nix b/pkgs/development/python-modules/aranet4/default.nix
index ecdc427138f7..95da1bb6ad8f 100644
--- a/pkgs/development/python-modules/aranet4/default.nix
+++ b/pkgs/development/python-modules/aranet4/default.nix
@@ -3,6 +3,7 @@
bleak,
buildPythonPackage,
fetchFromGitHub,
+ fetchpatch,
pytestCheckHook,
pythonOlder,
requests,
@@ -23,6 +24,15 @@ buildPythonPackage rec {
hash = "sha256-/FBrP4aceIX9dcZmm+k13PSAPuK4SQenjWqOAFPSvL8=";
};
+ patches = [
+ # https://github.com/Anrijs/Aranet4-Python/pull/62
+ (fetchpatch {
+ name = "fix-for-failing-test-with-bleak-1.1.0.patch";
+ url = "https://github.com/Anrijs/Aranet4-Python/pull/62/commits/0117633682050c77cd00ead1bce93375367d7a3c.patch";
+ hash = "sha256-S4Di6bKbapCpDdOIy4sSiG9dO7OZq5ixjjK+ux4EEp0=";
+ })
+ ];
+
build-system = [ setuptools ];
dependencies = [
diff --git a/pkgs/development/python-modules/bleak/default.nix b/pkgs/development/python-modules/bleak/default.nix
index 6ac36b12b90c..8fd97203fc4e 100644
--- a/pkgs/development/python-modules/bleak/default.nix
+++ b/pkgs/development/python-modules/bleak/default.nix
@@ -14,7 +14,7 @@
buildPythonPackage rec {
pname = "bleak";
- version = "1.0.1";
+ version = "1.1.1";
pyproject = true;
disabled = pythonOlder "3.9";
@@ -23,7 +23,7 @@ buildPythonPackage rec {
owner = "hbldh";
repo = "bleak";
tag = "v${version}";
- hash = "sha256-JHTyTHMMZDD75baQK3nf4R+8eW0Tt62CMTXb8eRKp94=";
+ hash = "sha256-z0Mxr1pUQWNEK01PKMV/CzpW+GeCRcv/+9BADts1FuU=";
};
postPatch = ''
diff --git a/pkgs/development/python-modules/bluetooth-adapters/default.nix b/pkgs/development/python-modules/bluetooth-adapters/default.nix
index b0d0e9d2cf5e..8a6f6c7e983a 100644
--- a/pkgs/development/python-modules/bluetooth-adapters/default.nix
+++ b/pkgs/development/python-modules/bluetooth-adapters/default.nix
@@ -22,7 +22,7 @@
buildPythonPackage rec {
pname = "bluetooth-adapters";
- version = "2.1.0";
+ version = "2.1.1";
pyproject = true;
disabled = pythonOlder "3.9";
@@ -31,7 +31,7 @@ buildPythonPackage rec {
owner = "Bluetooth-Devices";
repo = "bluetooth-adapters";
tag = "v${version}";
- hash = "sha256-euAyVSBmlMsPMUnxn8L7p0n939TQe4id+JTtUk4pHIY=";
+ hash = "sha256-M9Me+fTaw//wGVd9Ss9iYB7RMgfkxJZz2lT60lHe3Vg=";
};
outputs = [
@@ -71,7 +71,7 @@ buildPythonPackage rec {
meta = {
description = "Tools to enumerate and find Bluetooth Adapters";
homepage = "https://github.com/Bluetooth-Devices/bluetooth-adapters";
- changelog = "https://github.com/bluetooth-devices/bluetooth-adapters/blob/${src.tag}/CHANGELOG.md";
+ changelog = "https://github.com/Bluetooth-Devices/bluetooth-adapters/releases/tag/${src.tag}";
license = lib.licenses.asl20;
teams = [ lib.teams.home-assistant ];
};
diff --git a/pkgs/games/blightmud/default.nix b/pkgs/games/blightmud/default.nix
index d9fd0ade422e..0af177f0448f 100644
--- a/pkgs/games/blightmud/default.nix
+++ b/pkgs/games/blightmud/default.nix
@@ -14,8 +14,8 @@ rustPlatform.buildRustPackage rec {
version = "5.3.1";
src = fetchFromGitHub {
- owner = pname;
- repo = pname;
+ owner = "blightmud";
+ repo = "blightmud";
rev = "v${version}";
hash = "sha256-9GUul5EoejcnCQqq1oX+seBtxttYIUhgcexaZk+7chk=";
};
diff --git a/pkgs/games/duckmarines/default.nix b/pkgs/games/duckmarines/default.nix
index 36fdccc01c5a..5513731e2283 100644
--- a/pkgs/games/duckmarines/default.nix
+++ b/pkgs/games/duckmarines/default.nix
@@ -19,7 +19,7 @@ stdenv.mkDerivation rec {
desktopItem = makeDesktopItem {
name = "duckmarines";
- exec = pname;
+ exec = "duckmarines";
icon = icon;
comment = "Duck-themed action puzzle video game";
desktopName = "Duck Marines";
@@ -28,7 +28,7 @@ stdenv.mkDerivation rec {
};
src = fetchurl {
- url = "https://github.com/SimonLarsen/${pname}/releases/download/v${version}/${pname}-1.0c.love";
+ url = "https://github.com/SimonLarsen/duckmarines/releases/download/v${version}/duckmarines-1.0c.love";
sha256 = "1rvgpkvi4h9zhc4fwb4knhsa789yjcx4a14fi4vqfdyybhvg5sh9";
};
@@ -44,11 +44,11 @@ stdenv.mkDerivation rec {
mkdir -p $out/bin
mkdir -p $out/share/games/lovegames
- cp -v ${src} $out/share/games/lovegames/${pname}.love
+ cp -v ${src} $out/share/games/lovegames/duckmarines.love
- makeWrapper ${love}/bin/love $out/bin/${pname} --add-flags $out/share/games/lovegames/${pname}.love
+ makeWrapper ${love}/bin/love $out/bin/duckmarines --add-flags $out/share/games/lovegames/duckmarines.love
- chmod +x $out/bin/${pname}
+ chmod +x $out/bin/duckmarines
mkdir -p $out/share/applications
ln -s ${desktopItem}/share/applications/* $out/share/applications/
'';
diff --git a/pkgs/games/instawow/default.nix b/pkgs/games/instawow/default.nix
index a3f2d3c36f20..36d8e6b3cdc4 100644
--- a/pkgs/games/instawow/default.nix
+++ b/pkgs/games/instawow/default.nix
@@ -12,7 +12,7 @@ python3.pkgs.buildPythonApplication rec {
src = fetchFromGitHub {
owner = "layday";
- repo = pname;
+ repo = "instawow";
tag = "v${version}";
sha256 = "sha256-NFs8+BUXJEn64TDojG/xkH1O+zZurv0PWY+YDhu2mQY=";
};
diff --git a/pkgs/games/orthorobot/default.nix b/pkgs/games/orthorobot/default.nix
index 5278cd20c6e1..b53889159959 100644
--- a/pkgs/games/orthorobot/default.nix
+++ b/pkgs/games/orthorobot/default.nix
@@ -18,7 +18,7 @@ stdenv.mkDerivation rec {
src = fetchFromGitHub {
owner = "Stabyourself";
- repo = pname;
+ repo = "orthorobot";
rev = "v${version}";
sha256 = "1ca6hvd890kxmamsmsfiqzw15ngsvb4lkihjb6kabgmss61a6s5p";
};
@@ -31,7 +31,7 @@ stdenv.mkDerivation rec {
desktopItems = [
(makeDesktopItem {
name = "orthorobot";
- exec = pname;
+ exec = "orthorobot";
icon = icon;
comment = "Robot game";
desktopName = "Orthorobot";
diff --git a/pkgs/games/qtads/default.nix b/pkgs/games/qtads/default.nix
index 4de706b5c50d..90f6652ac658 100644
--- a/pkgs/games/qtads/default.nix
+++ b/pkgs/games/qtads/default.nix
@@ -18,7 +18,7 @@ mkDerivation rec {
src = fetchFromGitHub {
owner = "realnc";
- repo = pname;
+ repo = "qtads";
rev = "v${version}";
sha256 = "sha256-KIqufpvl7zeUtDBXUOAZxBIbfv+s51DoSaZr3jol+bw=";
};
diff --git a/pkgs/games/the-butterfly-effect/default.nix b/pkgs/games/the-butterfly-effect/default.nix
index 8e03d34c8d2b..e67c67e8b8da 100644
--- a/pkgs/games/the-butterfly-effect/default.nix
+++ b/pkgs/games/the-butterfly-effect/default.nix
@@ -15,7 +15,7 @@ mkDerivation rec {
src = fetchFromGitHub {
owner = "kaa-ching";
- repo = pname;
+ repo = "tbe";
tag = "v${version}";
sha256 = "1ag2cp346f9bz9qy6za6q54id44d2ypvkyhvnjha14qzzapwaysj";
};
diff --git a/pkgs/servers/web-apps/outline/default.nix b/pkgs/servers/web-apps/outline/default.nix
index ecdd6f5a169e..a2f9025ba9d3 100644
--- a/pkgs/servers/web-apps/outline/default.nix
+++ b/pkgs/servers/web-apps/outline/default.nix
@@ -14,13 +14,13 @@
stdenv.mkDerivation rec {
pname = "outline";
- version = "0.87.3";
+ version = "0.87.4";
src = fetchFromGitHub {
owner = "outline";
repo = "outline";
rev = "v${version}";
- hash = "sha256-hayA8zYSl4PFRlsK6n2881eef2J9Oy3FhiMFgdFgONY=";
+ hash = "sha256-gsQPDbKTzsXV8y8/xMxmhJM6pI+zDkx/r1Zk83ixb7k=";
};
nativeBuildInputs = [
@@ -35,7 +35,7 @@ stdenv.mkDerivation rec {
yarnOfflineCache = fetchYarnDeps {
yarnLock = "${src}/yarn.lock";
- hash = "sha256-1u9/I1H2BsUS5qPwNAdCrug3ekCTyWHd60kR9FXugV0=";
+ hash = "sha256-/bWDFIGElBc1lMODKTxmSkal9c4L1iTPd521/DVYyxo=";
};
configurePhase = ''
diff --git a/pkgs/top-level/all-packages.nix b/pkgs/top-level/all-packages.nix
index 349ec204bb2e..5b37605f35c3 100644
--- a/pkgs/top-level/all-packages.nix
+++ b/pkgs/top-level/all-packages.nix
@@ -5336,6 +5336,8 @@ with pkgs;
withQt = true;
};
+ lima-additional-guestagents = callPackage ../by-name/li/lima/additional-guestagents.nix { };
+
lld = llvmPackages.lld;
lldb = llvmPackages.lldb;
diff --git a/pkgs/by-name/da/dashy-ui/package.nix b/pkgs/by-name/da/dashy-ui/package.nix
index bb7be67a8035..7ff42949d6d0 100644
--- a/pkgs/by-name/da/dashy-ui/package.nix
+++ b/pkgs/by-name/da/dashy-ui/package.nix
@@ -8,9 +8,10 @@
yarn,
fixup-yarn-lock,
prefetch-yarn-deps,
+ nixosTests,
nodejs_20,
nodejs-slim_20,
- yq-go,
+ remarshal_0_17,
settings ? { },
}:
stdenv.mkDerivation (finalAttrs: {
@@ -26,15 +27,20 @@ stdenv.mkDerivation (finalAttrs: {
yarnLock = finalAttrs.src + "/yarn.lock";
hash = "sha256-r36w3Cz/V7E/xPYYpvfQsdk2QXfCVDYE9OxiFNyKP2s=";
};
+
+ passthru.tests = {
+ dashy = nixosTests.dashy;
+ };
+
# - If no settings are passed, use the default config provided by upstream
# - Despite JSON being valid YAML (and the JSON passing the config validator),
# there seem to be some issues with JSON in the final build - potentially due to
# the way the client parses things
# - Instead, we use `yq-go` to convert it to yaml
# Config validation needs to happen after yarnConfigHook, since it's what sets the yarn offline cache
preBuild = lib.optional (settings != { }) ''
echo "Writing settings override..."
- yq --output-format yml '${builtins.toFile "conf.json" ''${builtins.toJSON settings}''}' > user-data/conf.yml
+ json2yaml '${builtins.toFile "conf.json" (builtins.toJSON settings)}' user-data/conf.yml
yarn validate-config --offline
'';
installPhase = ''
@@ -59,8 +65,8 @@ stdenv.mkDerivation (finalAttrs: {
})
yarnBuildHook
nodejs_20
- # For yaml parsing
- yq-go
+ # For yaml conversion
+ remarshal_0_17
];
doDist = false;
meta = {
@@ -26,15 +27,20 @@ stdenv.mkDerivation (finalAttrs: {
# there seem to be some issues with JSON in the final build - potentially due to
# the way the client parses things
- # - Instead, we use `yq-go` to convert it to yaml
+ # - Instead, we use `remarshal` to convert it to yaml
# Config validation needs to happen after yarnConfigHook, since it's what sets the yarn offline cache
preBuild = lib.optional (settings != { }) ''